# Pinecone helpers for notebooks
This package contains helper functions for working with Pinecone in the context of a Jupyter or
Google Colab notebook.

## Google Colab
### Authenticate
This helper function displays a widget to allow the user to authenticate with Pinecone. The
resulting API key will be placed in the `PINECONE_API_KEY` environment variable.
#### Usage
To display the authentication widget:
```py
from pinecone_notebooks.colab import Authenticate

Authenticate()
```
The widget will be displayed for the user to authenticate. Note that any usage of the API key should
take place in a later cell. The user must complete the authentication flow before the
`PINECONE_API_KEY` environment variable can be used.
```py
from pinecone import Pinecone

api_key = os.environ.get('PINECONE_API_KEY')
pinecone_client = Pinecone(api_key=api_key)

# ... proceed to use pinecone_client to create indexes, upload data, query, etc.
```
##### source_tag
The `Authenticate` function has an optional `source_tag` parameter. Pinecone partners should set
this value to receive attribution credit for users of their notebooks who signup to Pinecone.
```py
from pinecone_notebooks.colab import Authenticate

Authenticate(source_tag='MyAwesomeApp')
```

## Jupyter
Coming soon!
